@@ -2,11 +2,11 @@ package Alien::Build::Plugin::Decode::Mojo;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 use Alien::Build::Plugin;
 
 # ABSTRACT: Plugin to extract links from HTML using Mojo::DOM or Mojo::DOM58
-our $VERSION = '1.98'; # VERSION
+our $VERSION = '2.32'; # VERSION
 
 
 sub _load ($;$)
@@ -26,7 +26,7 @@ sub _load ($;$)
 
 has _class => sub {
   return 'Mojo::DOM58' if _load 'Mojo::DOM58';
-  return 'Mojo::DOM'   if _load 'Mojo::DOM' && _load 'Mojolicious', 7.00;
+  return 'Mojo::DOM'   if _load 'Mojo::DOM' and _load 'Mojolicious', 7.00;
   return 'Mojo::DOM58';
 };
 
@@ -37,11 +37,13 @@ sub init
   $meta->add_requires('share' => 'URI' => 0);
   $meta->add_requires('share' => 'URI::Escape' => 0);
 
-  if($self->_class eq 'Mojo::DOM58')
+  my $class = $meta->prop->{plugin_decode_mojo_class} ||= $self->_class;
+
+  if($class eq 'Mojo::DOM58')
   {
     $meta->add_requires('share' => 'Mojo::DOM58' => '1.00');
   }
-  elsif($self->_class eq 'Mojo::DOM')
+  elsif($class eq 'Mojo::DOM')
   {
     $meta->add_requires('share' => 'Mojolicious' => '7.00');
     $meta->add_requires('share' => 'Mojo::DOM'   => '0');
@@ -57,7 +59,7 @@ sub init
     die "do not know how to decode @{[ $res->{type} ]}"
       unless $res->{type} eq 'html';
 
-    my $dom = $self->_class->new($res->{content});
+    my $dom = $class->new($res->{content});
 
     my $base = URI->new($res->{base});
 
@@ -103,7 +105,7 @@ Alien::Build::Plugin::Decode::Mojo - Plugin to extract links from HTML using Moj
 
 =head1 VERSION
 
-version 1.98
+version 2.32
 
 =head1 SYNOPSIS
 
@@ -195,6 +197,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
